importlib_resources: Read resources from Python packages
========================================================

Description
-----------

Read resources from Python packages

License
-------

Apache2

Upstream Contact
----------------

https://pypi.org/project/importlib-resources/

